This should use isIndenticalToWhenDefined.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@80039 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/VMCore/Instruction.cpp b/lib/VMCore/Instruction.cpp
index 332ecf9..815dd7e 100644
--- a/lib/VMCore/Instruction.cpp
+++ b/lib/VMCore/Instruction.cpp
@@ -168,11 +168,11 @@
 /// identical to the current one.  This means that all operands match and any
 /// extra information (e.g. load is volatile) agree.
 bool Instruction::isIdenticalTo(const Instruction *I) const {
-  return isIdenticalTo(I) &&
+  return isIdenticalToWhenDefined(I) &&
          SubclassOptionalData == I->SubclassOptionalData;
 }
 
 /// isIdenticalToWenDefined - This is like isIdenticalTo, except that it
 /// ignores the SubclassOptionalData flags, which specify conditions
 /// under which the instruction's result is undefined.
 bool Instruction::isIdenticalToWhenDefined(const Instruction *I) const {
@@ -168,11 +168,11 @@
 }
 
-/// isIdenticalToWenDefined - This is like isIdenticalTo, except that it
+/// isIdenticalToWhenDefined - This is like isIdenticalTo, except that it
 /// ignores the SubclassOptionalData flags, which specify conditions
 /// under which the instruction's result is undefined.